@@ -657,12 +657,11 @@ LinkContainer *BranchContainer::getLinkContainer() { return linkContainer; }
 
 void BranchContainer::linkTo(BranchContainer *pbc)
 {
+    originalParentBranchContainer = nullptr;
 
     if (!pbc)
         return;
 
-    originalParentBranchContainer = nullptr;
-
     pbc->linkContainer->addLink(upLink);
 }
 
@@ -805,10 +804,9 @@ void BranchContainer::updateUpLink()
 
     BranchContainer *pbc = nullptr;
 
-    if (tmpLinkedParentContainer) {
+    if (tmpLinkedParentContainer)
         // I am temporarily linked to tmpLinkedParentContainer
         pbc = tmpLinkedParentContainer;
-    }
     else if (originalParentBranchContainer)
         // I am moving with tmpParent, use original parent for link
         pbc = originalParentBranchContainer;
@@ -862,7 +860,7 @@ void BranchContainer::updateUpLink()
             upLink->setLinkStyle(LinkObj::NoLink);
         else {
             upLink->setLinkStyle(
-                tmpParentBI->mapDesign()->linkStyle(tmpParentBI->depth()));
+                branchItem->mapDesign()->linkStyle(branchItem->depth()));
         }
     }
 
@@ -1415,7 +1413,9 @@ void BranchContainer::reposition()
         // on MovingState
         if (pbc) {
             if (pbc->hasFloatingBranchesLayout()) {
-                if (pos().x() > 0)
+                if (scenePos().x() > pbc->scenePos().x())   // FIXME-2 problematic for rotated elements...
+                                                            // but OTOH using relative coord
+                                                            // often pos.x() == 0
                     orientation = RightOfParent;
                 else
                     orientation = LeftOfParent;
