@@ -1,7 +1,12 @@
 #include "dockeditor.h"
 
+#include "mainwindow.h"
 #include "vymmodel.h"
 
+#include <QCloseEvent>
+
+extern Main *mainWindow;
+
 DockEditor::DockEditor() { init(); }
 DockEditor::DockEditor(QString title, QWidget *p, VymModel *m)
     : QDockWidget(title, p)
@@ -24,3 +29,9 @@ void DockEditor::changeTopLevel(bool topLevel)
     else
         setWindowTitle(editorTitle);
 }
+
+void DockEditor::closeEvent(QCloseEvent *event)
+{
+    // Pass event on to overloaded editors (TreeEditor, SlideEditor)
+    ((DockEditor*)widget())->closeEvent(event);
+}
