@@ -12,13 +12,14 @@ class TreeEditor : public QTreeView {
     Q_OBJECT
 
   public:
-    TreeEditor(VymModel *m = NULL);
+    TreeEditor(VymModel *m = nullptr);
     ~TreeEditor();
     void init();
     QModelIndex getSelectedIndex();
 
   protected:
     virtual void contextMenuEvent(QContextMenuEvent *e);
+    virtual void closeEvent(QCloseEvent *event);
 
   private slots:
     void cursorUp();
