@@ -36,6 +36,8 @@ class ZipAgent;
 class QGraphicsScene;
 class QJsonObject;
 
+// Used for getTargets() and getLinkedMaps()
+// For each ID store heading and optionally also vymLink
 typedef QMap<uint, QStringList> ItemList;
 
 class VymModel : public TreeModel {
@@ -900,18 +902,6 @@ class VymModel : public TreeModel {
     void setSelectionBrushColor(QColor);
     QColor getSelectionBrushColor();
 
-    ////////////////////////////////////////////
-    // Iterating and selecting branches
-    ////////////////////////////////////////////
-  public:
-    void newBranchIterator(const QString &itname,
-                      BranchItem *bi = nullptr,             //! All branches or only subtree
-                      bool deepLevelsFirst = false);        //! Named iterator
-    BranchItem* nextBranchIterator(const QString &itname);  //! next branch via iterator
-  private:
-    QHash <QString, QList <QUuid>> branchIterators;
-    QHash <QString, int> branchIteratorsCurrentIndex;
-
     ////////////////////////////////////////////
     // Slide related
     ////////////////////////////////////////////
