@@ -10,6 +10,7 @@ class BranchItem;
 class AttributeWrapper;
 class BranchWrapper;
 class ImageWrapper;
+class ItemListWrapper;
 class VymModel;
 class XLinkWrapper;
 
@@ -44,6 +45,7 @@ class VymModelWrapper : public QObject {
     QString getTitle();
     QString getLinkColorHint();
     QString getSelectionString();
+    double getZoom();
     bool hasBackgroundImage();
     bool loadBackgroundImage(const QString &imagePath);
     bool loadBranchReplace(QString filename, BranchWrapper *bw);
@@ -52,8 +54,7 @@ class VymModelWrapper : public QObject {
     void moveSlideDown();
     void moveSlideUp(int n);
     void moveSlideUp();
-    void newBranchIterator(const QString &itname, bool deepLevelsFirst = false);
-    Q_INVOKABLE BranchWrapper* nextBranch(const QString &itname);
+    Q_INVOKABLE ItemListWrapper* itemList();
     void paste();
     void redo();
     void remove();
@@ -78,7 +79,7 @@ class VymModelWrapper : public QObject {
     void setBackgroundColor(const QString &color);
     void setBackgroundImageName(const QString &name);
     void setComment(const QString &s);
-    void setLinkStyle(const QString &style);
+    void setLinkStyle(const QString &style, int depth = -1);
     void setLinkColorHint(const QString &hint);
     void setRotationView(float a);
     void setTitle(const QString &s);
@@ -93,7 +94,7 @@ class VymModelWrapper : public QObject {
     void unsetBackgroundImage();
 
   private:
-    VymModel *model;
+    VymModel *modelInt;
 };
 
 #endif
